@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.5 2005/11/29 16:38:09 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.cc,v 1.6 2006/07/10 03:12:57 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -16,6 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
+#include <gtkmm/fileselection.h>
 #include "examplewindow.h"
 #include <iostream>
 
@@ -70,6 +71,8 @@ void ExampleWindow::on_button_folder_clicked()
       break;
     }
   }
+#else
+  std::cout << "Gtk::FileSelection is deprecated and gtkmm has not been compiled with support for deprecated widgets" << std::endl;
 #endif //GTKMM_DISABLE_DEPRECATED
 }
 
@@ -103,5 +106,7 @@ void ExampleWindow::on_button_file_clicked()
       break;
     }
   }
+#else
+  std::cout << "Gtk::FileSelection is deprecated and gtkmm has not been compiled with support for deprecated widgets" << std::endl;
 #endif //GTKMM_DISABLE_DEPRECATED
 }
