@@ -1,4 +1,4 @@
-//$Id: examplewindow.h,v 1.1 2002/11/28 14:06:17 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.h,v 1.2 2006/07/10 03:12:58 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -19,7 +19,9 @@
 #ifndef GTKMM_EXAMPLEWINDOW_H
 #define GTKMM_EXAMPLEWINDOW_H
 
-#include <gtkmm.h>
+#include <gtkmm/window.h>
+#include <gtkmm/buttonbox.h>
+#include <gtkmm/button.h>
 
 class ExampleWindow : public Gtk::Window
 {
