@@ -1,4 +1,4 @@
-//$Id: idleexample.h,v 1.2 2004/02/10 14:49:17 murrayc Exp $ -*- c++ -*-
+//$Id: idleexample.h,v 1.3 2006/07/10 03:15:24 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2003 gtkmm development team
  *
@@ -19,7 +19,10 @@
 #ifndef GTKMM_EXAMPLE_IDLEEXAMPLE_H
 #define GTKMM_EXAMPLE_IDLEEXAMPLE_H
 
-#include <gtkmm.h>
+#include <gtkmm/window.h>
+#include <gtkmm/box.h>
+#include <gtkmm/button.h>
+#include <gtkmm/progressbar.h>
 #include <iostream>
 
 class IdleExample : public Gtk::Window
