@@ -1,4 +1,4 @@
-//$Id: labeledoptionmenu.h,v 1.1.1.1.6.1 2005/11/29 16:37:12 murrayc Exp $ -*- c++ -*-
+//$Id: labeledoptionmenu.h,v 1.3 2006/07/10 03:15:30 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -19,7 +19,9 @@
 #ifndef GTKMM_EXAMPLE_RANGEWIDGETS_LABELEDOPTIONMENU_H
 #define GTKMM_EXAMPLE_RANGEWIDGETS_LABELEDOPTIONMENU_H
 
-#include <gtkmm.h>
+#include <gtkmm/box.h>
+#include <gtkmm/label.h>
+#include <gtkmm/menu.h>
 
 class LabeledOptionMenu : public Gtk::HBox
 {
