@@ -1,4 +1,4 @@
-//$Id: examplewindow.h,v 1.2 2004/10/30 12:49:41 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.h,v 1.3 2006/07/10 03:16:13 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -19,7 +19,14 @@
 #ifndef GTKMM_EXAMPLEWINDOW_H
 #define GTKMM_EXAMPLEWINDOW_H
 
-#include <gtkmm.h>
+#include <gtkmm/window.h>
+#include <gtkmm/scrolledwindow.h>
+#include <gtkmm/treeview.h>
+#include <gtkmm/box.h>
+#include <gtkmm/liststore.h>
+#include <gtkmm/treemodelfilter.h>
+#include <gtkmm/button.h>
+#include <gtkmm/buttonbox.h>
 
 class ExampleWindow : public Gtk::Window
 {
