@@ -19,9 +19,8 @@
 #ifndef __TICTACTOE_H__
 #define __TICTACTOE_H__
 
-#include <gdk--.h>
-#include <gtk--/box.h>
-#include <gtk--/togglebutton.h>
+#include <gtkmm/box.h>
+#include <gtkmm/togglebutton.h>
 
 class TicTacToe: public Gtk::VBox
 {
@@ -36,7 +35,7 @@ class TicTacToe: public Gtk::VBox
 
     void clear();
 
-    SigC::Signal0<void> tictactoe;
+    sigc::signal<void> tictactoe;
 
     TicTacToe();
     ~TicTacToe();
